@@ -9,7 +9,7 @@ def _subprocess_copy(text, args_list):
     p.communicate(input=text.encode('utf-8'))
 
 
-def copy(text, cmd):
+def copy(text, cmd=None):
     """
     Copy text to OS clipboard.
     """
@@ -20,6 +20,6 @@ def copy(text, cmd):
         if sys.platform == 'darwin':
             cmd = 'pbcopy w'
         else: # For Linux, BSD, cygwin, etc.
-            cmd = 'xclip -selection -clipboard'
+            cmd = 'xclip -selection clipboard'
 
     _subprocess_copy(text, cmd.split())
