@@ -12,6 +12,7 @@ from bs4 import BeautifulSoup
 from kitchen.text.display import wrap
 
 from . import exceptions
+from .config import Config
 from .packages import praw
 from .packages.praw.errors import InvalidSubreddit
 from .packages.praw.helpers import normalize_url
@@ -151,7 +152,7 @@ class Content(object):
             data['body'] = comment.body
             data['html'] = comment.body_html
             data['created'] = cls.humanize_timestamp(comment.created_utc)
-            data['score'] = '{0} pts'.format(
+            data['score'] = '{0}'.format(
                 '-' if comment.score_hidden else comment.score)
             data['author'] = name
             data['is_author'] = (name == sub_name)
@@ -186,7 +187,7 @@ class Content(object):
             data['nsfw'] = comment.over_18
             data['subreddit'] = six.text_type(comment.subreddit)
             data['url_type'] = 'selfpost'
-            data['score'] = '{0} pts'.format(
+            data['score'] = '{0}'.format(
                 '-' if comment.score_hidden else comment.score)
             data['likes'] = comment.likes
             data['created'] = cls.humanize_timestamp(comment.created_utc)
@@ -232,8 +233,9 @@ class Content(object):
         data['html'] = sub.selftext_html or ''
         data['created'] = cls.humanize_timestamp(sub.created_utc)
         data['created_long'] = cls.humanize_timestamp(sub.created_utc, True)
-        data['comments'] = '{0} comments'.format(sub.num_comments)
-        data['score'] = '{0} pts'.format('-' if sub.hide_score else sub.score)
+        data['created_exact'] = cls.exact_timestamp(sub.created_utc)
+        data['comments'] = sub.num_comments
+        data['score'] = '{0}'.format('-' if sub.hide_score else sub.score)
         data['author'] = name
         data['permalink'] = sub.permalink
         data['subreddit'] = six.text_type(sub.subreddit)
@@ -252,9 +254,12 @@ class Content(object):
                 cls.humanize_timestamp(sub.edited))
             data['edited_long'] = '(edit {})'.format(
                 cls.humanize_timestamp(sub.edited, True))
+            data['edited_exact'] = '(edit {})'.format(
+                cls.exact_timestamp(sub.edited))
         else:
             data['edited'] = ''
             data['edited_long'] = ''
+            data['edited_exact'] = ''
 
         if sub.url.split('/r/')[-1] == sub.permalink.split('/r/')[-1]:
             data['url'] = 'self.{0}'.format(data['subreddit'])
@@ -397,6 +402,18 @@ class Content(object):
         else:
             return '%dyr' % years
 
+    @staticmethod
+    def exact_timestamp(utc_timestamp):
+        dt = datetime.fromtimestamp(utc_timestamp)
+
+        # https://stackoverflow.com/a/765990
+        yearsago = ((datetime.now() - dt).days / 365.2425)
+
+        if yearsago > 0:
+            return six.u(dt.strftime("%Y-%m-%d"))
+        else:
+            return six.u(dt.strftime("%m-%d %H:%M"))
+
     @staticmethod
     def wrap_text(text, width):
         """
@@ -563,18 +580,23 @@ class SubredditContent(Content):
     list for repeat access.
     """
 
-    def __init__(self, name, submissions, loader, order=None,
-                 max_title_rows=4, query=None, filter_nsfw=False):
+    def __init__(self, config, name, submissions, loader, order=None,
+                 query=None, filter_nsfw=False):
 
+        self.config = config
         self.name = name
         self.order = order
         self.query = query
-        self.max_title_rows = max_title_rows
         self.filter_nsfw = filter_nsfw
         self._loader = loader
         self._submissions = submissions
         self._submission_data = []
 
+        if self.config['look_and_feel'] == 'default':
+            self.max_title_rows = 4
+        else:
+            self.max_title_rows = 1
+
         # Verify that content exists for the given submission generator.
         # This is necessary because PRAW loads submissions lazily, and
         # there is is no other way to check things like multireddits that
@@ -588,7 +610,7 @@ class SubredditContent(Content):
             raise exceptions.NoSubmissionsError(full_name)
 
     @classmethod
-    def from_name(cls, reddit, name, loader, order=None, query=None):
+    def from_name(cls, reddit, config, name, loader, order=None, query=None):
         """
         Params:
             reddit (praw.Reddit): Instance of the reddit api.
@@ -796,7 +818,7 @@ class SubredditContent(Content):
         filter_nsfw = (reddit.user and reddit.user.over_18 is False)
 
         # We made it!
-        return cls(display_name, submissions, loader, order=display_order,
+        return cls(config, display_name, submissions, loader, order=display_order,
                    query=query, filter_nsfw=filter_nsfw)
 
     @property
@@ -847,17 +869,24 @@ class SubredditContent(Content):
                     data = self.strip_praw_comment(submission)
 
                 data['index'] = len(self._submission_data) + 1
-                # Add the post number to the beginning of the title
-                data['title'] = '{0}. {1}'.format(data['index'], data['title'])
+
+                # Add the post number to the beginning of the title if necessary
+                if self.config['look_and_feel'] == 'default':
+                    data['title'] = '{0}. {1}'.format(data['index'], data['title'])
+
                 self._submission_data.append(data)
 
         # Modifies the original dict, faster than copying
         data = self._submission_data[index]
-        data['split_title'] = self.wrap_text(data['title'], width=n_cols)
-        if len(data['split_title']) > self.max_title_rows:
-            data['split_title'] = data['split_title'][:self.max_title_rows-1]
-            data['split_title'].append('(Not enough space to display)')
-        data['n_rows'] = len(data['split_title']) + 3
+
+        if self.config['look_and_feel'] == 'compact':
+            data['n_rows'] = 2
+        elif self.config['subreddit_format']:
+            data['n_rows'] = self.config['subreddit_format'].count('\n') + 1
+        else:
+            data['split_title'] = self.wrap_text(data['title'], width=n_cols)
+            data['n_rows'] = len(data['split_title']) + 3
+
         data['h_offset'] = 0
 
         return data
